@@ -123,18 +123,15 @@ class AbstractDeconstructor:
             tuple(["Sigma", "Z"]), pragmatic,
             self.settings.deconst_full_tolerance)
 
-        D["complete"] = len(complete_relatives)
         yield complete_relatives
 
         t_sigma_relatives = [m for m in t_sigma_relatives
                              if m in relative_finder]
 
-        D["tsigma"] = len(t_sigma_relatives)
         yield t_sigma_relatives
 
         sigma_z_relatives = [m for m in sigma_z_relatives
                              if m in relative_finder]
-        D["sigmaz"] = len(sigma_z_relatives)
         yield sigma_z_relatives
 
     def clean_ts_queue(self, deleted):
@@ -218,9 +215,6 @@ class SerialDeconstructor(AbstractDeconstructor):
 
             for log in result_deque:
                 self.clean_ts_queue(log.deleted)
-                if log.state == DeconstructionInfo.State.DECONSTRUCTED:
-                    D["c_deconstructed"] += 1
-
                 yield log
 
     def run_t_sigma_deconstruction(self, level, pragmatic, database, relatives):
@@ -380,9 +374,6 @@ class ParallelDeconstructor(AbstractDeconstructor):
         ).run()
 
         for log_info in result_deque:
-            if log_info.state == DeconstructionInfo.State.DECONSTRUCTED:
-                D["c_deconstructed"] += 1
-
             if self.tsigma_process:
                 self.tsigma_inputs.put(Upgrade(deletes=log_info.deleted))
             yield log_info
